stac.nonparametric_tests.finner_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.finner_test

`stac.nonparametric_tests.` `finner_test`(ranks, control=None)

  Performs a Finner post-hoc test using the pivot quantities obtained by a ranking test. Tests the hypothesis that the ranking of the control method is different to each of the other methods.

  Parameters: | pivots : dictionary_like A dictionary with format ‘groupname’:’pivotal quantity’ control : string optional The name of the control method, default the group with minimum ranking
  Returns: | Comparions : array-like Strings identifier of each comparison with format ‘group_i vs group_j’ Z-values : array-like The computed Z-value statistic for each comparison. p-values : array-like The associated p-value from the Z-distribution wich depends on the index of the comparison Adjusted p-values : array-like The associated adjusted p-values wich can be compared with a significance level

  References

  8. Finner, On a monotonicity problem in step-down multiple test procedures, Journal of the American Statistical Association 88 (1993) 920–923.

### Navigation

- index
- STAC Release Candidate documentation »